% SHEARHEAT calculates a tau(i,j) matrix with the spacial distribution of shear stress (taudat).
%   This distribution will be used to compute the shear heating rate. The shear heating
%   is assumed to be distributed over a width 2*Dx centered about the top of the slab, and
%   therefore affects the nodes inmediately to the left and right of the top of the slab

% Script component of TEMSPOL: a MATLAB thermal model for deep subduction
% zones including major phase transformations.
% A.M. Negredo, J.L. Valera and E. Carminati (2002)


% The following parameters were computed in velo.m
%   x4=x3-L*sin(dip);
%   x4old=x3old-L*sin(dip);
%   c=za+Vs*sin(dip)*time+cot(dip)*(x0+Vs*cos(dip)*time);

% The following parameters were computed in init_shearheat.m
%   W=2*Dx;             % Shear width
%   h=W/2*tan(dip);     % Half-height of the area of shear heating 



x4up=x4-h*sin(dip);
x4upold=x4old-h*sin(dip);
x4down=x4+h*sin(dip);
x4downold=x4old+h*sin(dip);

    z3x4=-cot(dip)*x4+c;
z3x4upold=-cot(dip)*x4upold+c;
z3x4down=-cot(dip)*x4down+c;

% Setting the interesting points of the grid

ix4up=round(x4up/Dx+1);             % imin
ix4downold=round(x4downold/Dx+1);   % imax
jx4down=round(z3x4down/Dz+1);       % jmin
jx4upold=round(z3x4upold/Dz+1);     % jmax


for j=jx4down:1:jx4upold
    z=(j-1)*Dz;
    for i=ix4up:1:ix4downold
        x=(i-1)*Dx;
        % diagonal of nodes to the left of the top of the slab
	    zci_up=tan(dip)*x+za+L-tan(dip)*x1+h;
        % diagonal of nodes to the right of the top of the slab
        zci_down=tan(dip)*x+za+L-tan(dip)*x1-h;
        z3=-cot(dip)*x+c; % front of the slab at current time
        if z>=z3
            if z>=zci_down & z<=zci_up
                tau(i,j)=taudat;
            end
        end
    end
end

clear z x zci_up zci_down x4up x4down x4upold x4downold z3x4 z3x4upold z3x4down ix4up ix4downold jx4down jx4upold;